@@ -203,6 +203,44 @@ class ChromeAutofill(FileActionProvider):
                _('Clean file'))
 
 
+
+class ChromeDatabases(FileActionProvider):
+    """Action to clean Databases.db in Google Chrome/Chromium"""
+    action_key = 'chrome.databases_db'
+
+    def get_commands(self):
+        for path in self.get_paths():
+            yield Command.Function( \
+                path, \
+                Special.delete_chrome_databases_db, \
+               _('Clean file'))
+
+
+class ChromeFavicons(FileActionProvider):
+    """Action to clean 'Favicons' file in Google Chrome/Chromium"""
+    action_key = 'chrome.favicons'
+
+    def get_commands(self):
+        for path in self.get_paths():
+            yield Command.Function( \
+                path, \
+                Special.delete_chrome_favicons, \
+               _('Clean file'))
+
+
+
+class ChromeHistory(FileActionProvider):
+    """Action to clean 'History' file in Google Chrome/Chromium"""
+    action_key = 'chrome.history'
+
+    def get_commands(self):
+        for path in self.get_paths():
+            yield Command.Function( \
+                path, \
+                Special.delete_chrome_history, \
+               _('Clean file'))
+
+
 class ChromeKeywords(FileActionProvider):
     """Action to clean 'keywords' table in Google Chrome/Chromium"""
     action_key = 'chrome.keywords'
