@@ -59,7 +59,7 @@ def diagnostic_info():
     for env in envs:
         s += "\nos.getenv('%s') = %s" % (env, os.getenv(env))
     s += "\nos.expanduser('~') = %s" % os.path.expanduser('~')
-    if 'linux2' == sys.platform:
+    if sys.platform.startswith('linux'):
         if hasattr(platform, 'linux_distribution'):
             s += "\nplatform.linux_distribution() = %s" % str(platform.linux_distribution())
         else:
@@ -73,12 +73,5 @@ def diagnostic_info():
     if 'nt' == os.name:
         s += "\nwin32com.shell.shell.IsUserAnAdmin() = %s" % shell.IsUserAnAdmin()
     s += "\n__file__ = %s" % __file__
-    try:
-        if 'nt' == os.name:
-            for p in Windows.enumerate_processes():
-                s += '\nrunning process: %s' % p
-    except:
-        traceback.print_exc()
-        s += '\nenumerate_process: ' + str(sys.exc_info()[1])
 
     return s
