@@ -41,7 +41,6 @@ import TestOptions
 import TestRecognizeCleanerML
 import TestSpecial
 import TestUpdate
-import TestWinapp
 import TestWorker
 
 
@@ -58,7 +57,6 @@ suites = [ TestAction.suite(),
            TestRecognizeCleanerML.suite(),
            TestSpecial.suite(),
            TestUpdate.suite(),
-           TestWinapp.suite(),
            TestWorker.suite() ]
 
 if 'posix' == os.name:
@@ -66,7 +64,9 @@ if 'posix' == os.name:
     suites.append(TestUnix.suite())
 
 if 'nt' == os.name:
+    import TestWinapp
     import TestWindows
+    suites.append(TestWinapp.suite())
     suites.append(TestWindows.suite())
 
 def suite():
